Code edit (1 edits merged)
Please save this source code
User prompt
ensure that there is alwas a objdash generated before there is an objspikey
Code edit (10 edits merged)
Please save this source code
User prompt
ensure at least one objjump is generated when the avoid event begins
Code edit (5 edits merged)
Please save this source code
User prompt
add a console.log when the objevent is being destroyed
Code edit (3 edits merged)
Please save this source code
User prompt
Please fix the bug: 'Uncaught ReferenceError: fase is not defined' in or related to this line: 'var objSpikeyIncrease1 = fase;' Line Number: 1324
Code edit (1 edits merged)
Please save this source code
User prompt
allow to have 2 objspikey to be on the screen at the same time
Code edit (3 edits merged)
Please save this source code
User prompt
ensure that function destroyspikey destroys all instances of objspikey
Code edit (4 edits merged)
Please save this source code
User prompt
Please fix the bug: 'TypeError: spikeys.length is not a function' in or related to this line: 'for (var i = 0; i < spikeys.length(); i++) {' Line Number: 1287
Code edit (5 edits merged)
Please save this source code
User prompt
Please fix the bug: 'TypeError: spikeys.length is not a function' in or related to this line: 'for (var i = 0; i < spikeys.length(); i++) {' Line Number: 1287
Code edit (1 edits merged)
Please save this source code
Code edit (4 edits merged)
Please save this source code
User prompt
ad a second objspikey at traveleddistance 1000 and a third objspikey once traveleddistance has reached 3000
Code edit (9 edits merged)
Please save this source code
User prompt
ensure objNightFilter is above the city when being added to the game
Code edit (6 edits merged)
Please save this source code
User prompt
Please fix the bug: 'TypeError: Cannot read properties of undefined (reading 'destroy')' in or related to this line: 'objNightFilter.destroy();' Line Number: 2030
Code edit (1 edits merged)
Please save this source code
Code edit (1 edits merged)
Please save this source code
===================================================================
--- original.js
+++ change.js
@@ -1206,10 +1206,10 @@
return obstacle instanceof ObjSPIKEY;
}).length >= 1) {
return;
}
- // Add a third objspikey at traveleddistance 3000
- if (Math.floor(distanceTraveled) === 3000) {
+ // Add a third objspikey at traveleddistance 2000
+ if (Math.floor(distanceTraveled) === 2000) {
var objSPIKEY3 = new ObjSPIKEY();
objSPIKEY3.x = game.width;
objSPIKEY3.y = hero.y;
obstacles.push(objSPIKEY3);
2d cyberpunk particle of a dash ability. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
blue jetfuel. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
pixel art speech bubble that says "?" neon color. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
pixel art speech bubble that says "Go" neon color. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
pixel art speech bubble that says "Ok" neon color.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
pixel art of a bubble a wing inside in neon color.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
pixel art bubble with 2 fast foward arrows neon color. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Gray Cyber neon lit logo of the word Rush. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
side profile of a flying car in the art style of a 16 bit neon cyberpunk game. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
retro cyberpunk datadisk in neon colors. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
retro cyberpunk pole flag in neon colors with the words 'events' on it.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
retro sign that says "Hold to Dash" in neon colors. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
retro sign that says "Tap to Move" in neon colors.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
retro sign that says "catch" with an flying drone symbol in neon colors.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
retro flying drone in neon colors.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
retro sign that says "Survive" with an face symbol in neon colors... Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
neon colored cyberpunk round electricity. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
SynthwaveMusic
Music
snd_letsgo
Sound effect
snd_announcer
Sound effect
snd_powerup
Sound effect
snd_dataacquire
Sound effect
snd_walkie
Sound effect
snd_nice
Sound effect
snd_carhonk
Sound effect
snd_enemy
Sound effect
snd_sphere
Sound effect
snd_windup
Sound effect
snd_spikey
Sound effect
snd_drone
Sound effect